@@ -6,11 +6,11 @@
 /*
  * Copyright (c) 2007-2015 The OpenRC Authors.
  * See the Authors file at the top-level directory of this distribution and
- * https://github.com/OpenRC/openrc/blob/master/AUTHORS
+ * https://github.com/OpenRC/openrc/blob/HEAD/AUTHORS
  *
  * This file is part of OpenRC. It is subject to the license terms in
  * the LICENSE file found in the top-level directory of this
- * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * distribution and at https://github.com/OpenRC/openrc/blob/HEAD/LICENSE
  * This file may not be copied, modified, propagated, or distributed
  *    except according to the terms contained in the LICENSE file.
  */
@@ -32,7 +32,7 @@ get_shell_value(char *string)
 	char *p = string;
 	char *e;
 
-	if (! string)
+	if (!string)
 		return NULL;
 
 	if (*p == '\'')
@@ -76,9 +76,10 @@ rc_deptree_free(RC_DEPTREE *deptree)
 		free(di);
 		di = di2;
 	}
+
+	/* Use free() here since rc_deptree_free should not call itself */
 	free(deptree);
 }
-librc_hidden_def(rc_deptree_free)
 
 static RC_DEPINFO *
 get_depinfo(const RC_DEPTREE *deptree, const char *service)
@@ -109,7 +110,6 @@ RC_DEPTREE *
 rc_deptree_load(void) {
 	return rc_deptree_load_file(RC_DEPTREE_CACHE);
 }
-librc_hidden_def(rc_deptree_load)
 
 RC_DEPTREE *
 rc_deptree_load_file(const char *deptree_file)
@@ -144,7 +144,7 @@ rc_deptree_load_file(const char *deptree_file)
 		if (strcmp(type, "service") == 0) {
 			/* Sanity */
 			e = get_shell_value(p);
-			if (! e || *e == '\0')
+			if (!e || *e == '\0')
 				continue;
 			depinfo = xmalloc(sizeof(*depinfo));
 			TAILQ_INIT(&depinfo->depends);
@@ -173,7 +173,6 @@ rc_deptree_load_file(const char *deptree_file)
 
 	return deptree;
 }
-librc_hidden_def(rc_deptree_load_file)
 
 static bool
 valid_service(const char *runlevel, const char *service, const char *type)
@@ -459,7 +458,6 @@ rc_deptree_depend(const RC_DEPTREE *deptree,
 		rc_stringlist_add(svcs, svc->value);
 	return svcs;
 }
-librc_hidden_def(rc_deptree_depend)
 
 RC_STRINGLIST *
 rc_deptree_depends(const RC_DEPTREE *deptree,
@@ -487,7 +485,6 @@ rc_deptree_depends(const RC_DEPTREE *deptree,
 	rc_stringlist_free(visited);
 	return sorted;
 }
-librc_hidden_def(rc_deptree_depends)
 
 RC_STRINGLIST *
 rc_deptree_order(const RC_DEPTREE *deptree, const char *runlevel, int options)
@@ -498,7 +495,7 @@ rc_deptree_order(const RC_DEPTREE *deptree, const char *runlevel, int options)
 	RC_STRINGLIST *services;
 
 	bootlevel = getenv("RC_BOOTLEVEL");
-	if (! bootlevel)
+	if (!bootlevel)
 		bootlevel = RC_LEVEL_BOOT;
 
 	/* When shutting down, list all running services */
@@ -543,7 +540,6 @@ rc_deptree_order(const RC_DEPTREE *deptree, const char *runlevel, int options)
 	rc_stringlist_free(types);
 	return services;
 }
-librc_hidden_def(rc_deptree_order)
 
 
 /* Given a time, recurse the target path to find out if there are
@@ -633,7 +629,6 @@ rc_newer_than(const char *source, const char *target,
 
 	return mtime_check(source, target, true, newest, file);
 }
-librc_hidden_def(rc_newer_than)
 
 bool
 rc_older_than(const char *source, const char *target,
@@ -641,7 +636,6 @@ rc_older_than(const char *source, const char *target,
 {
 	return mtime_check(source, target, false, oldest, file);
 }
-librc_hidden_def(rc_older_than)
 
 typedef struct deppair
 {
@@ -737,7 +731,6 @@ rc_deptree_update_needed(time_t *newest, char *file)
 
 	return newer;
 }
-librc_hidden_def(rc_deptree_update_needed)
 
 /* This is a 7 phase operation
    Phase 1 is a shell script which loads each init script and config in turn
@@ -1081,7 +1074,6 @@ rc_deptree_update(void)
 	}
 
 	rc_stringlist_free(config);
-	rc_deptree_free(deptree);
+	free(deptree);
 	return retval;
 }
-librc_hidden_def(rc_deptree_update)
